@@ -1,10 +1,10 @@
-package Tsk::Fs::File;
+package Tsk::Fs::Dir;
 use 5.012005;
 use strict;
 use warnings;
 use Tsk;
 require Exporter;
-our $VERSION = '0.05';
+our $VERSION = '0.051';
 
 our @ISA = qw(Exporter);
 our @EXPORT = @Tsk::EXPORT;
