@@ -4,11 +4,14 @@ use warnings;
 use lib './lib';
 use lib './blib/arch/auto/Tsk';
 use Tsk;
-use Tsk::Fs::Iterator2;
+use Tsk::Iterator::FileImg;
 use Devel::Peek;
 ## Overview: This sample illustrates traversing
 ## every directory and file in the filesystem
-my $iter = Tsk::Fs::Iterator2->new("testdata/testimage001.001");
+
+my $image_path = $ARGV[0] || "testdata/testimage001.001";
+print "Opening image $image_path\n";
+my $iter = Tsk::Iterator::FileImg->new($image_path);
 my $file_count = 0;
 my $dir_count = 0;
 while(my $file = $iter->next()) { 
@@ -19,11 +22,11 @@ while(my $file = $iter->next()) {
         $ctime = $file->getMeta()->getCTime();
         $type = $file->getMeta()->getType();
         $inode = $file->getMeta()->getAddr();
-        my $fullpath = $iter->{tsk_fs_iterator}->get_current_path();
+        my $fullpath = $iter->{tsk_iter_fsfile}->get_current_path();
         $fullpath .= "/".$file->getFileName();
         print "FILE inode=$inode path=$fullpath\n";
     } elsif (ref($file) eq "Tsk::Fs::Dir" ) {
-        my $fullpath = $iter->{tsk_fs_iterator}->get_current_path();
+        my $fullpath = $iter->{tsk_iter_fsfile}->get_current_path();
         print "DIR $fullpath\n";
         $type = $file->getFsFile()->getMeta()->getType();
     } else {
